@@ -2,8 +2,8 @@ package Catalyst::Plugin::ChainedURI;
 BEGIN {
   $Catalyst::Plugin::ChainedURI::AUTHORITY = 'cpan:GETTY';
 }
-BEGIN {
-  $Catalyst::Plugin::ChainedURI::VERSION = '0.002';
+{
+  $Catalyst::Plugin::ChainedURI::VERSION = '0.003';
 }
 # ABSTRACT: Simple way to get an URL to an action from chained catalyst controller
 use strict;
@@ -21,10 +21,8 @@ sub chained_uri {
 	
 	die "Catalyst::Plugin::ChainedURI needs Chained action as target (given: ".$controller."->".$action_for.")" if !$action->attributes->{Chained};
 	die "Catalyst::Plugin::ChainedURI needs the end of the chain as target (given: ".$controller."->".$action_for.")" if $action->attributes->{CaptureArgs};
-	
-	if ($c->log->is_debug) {
-		$c->log->debug('ChainedURI '.$controller.'->'.$action_for.' '.join(',',@ca));
-	}
+
+	$c->log->debug('ChainedURI '.$controller.'->'.$action_for.' '.join(',',map { defined $_ ? $_ : "" } @ca)) if $c->debug;
 
 	my @captures;
 	my $curr = $action;
@@ -52,7 +50,7 @@ sub chained_uri {
 	}
 	
 	@captures = reverse @captures;
-
+	
 	return $c->uri_for_action($action,\@captures,@ca);
 }
 
@@ -68,7 +66,7 @@ Catalyst::Plugin::ChainedURI - Simple way to get an URL to an action from chaine
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
